@@ -1,6 +1,6 @@
 from gym.envs.registration import register
 
-__version__ = '0.0.6'
+__version__ = '0.0.7'
 
 register(
     id="TwoLinkArmEnv-v0",
@@ -10,4 +10,9 @@ register(
 register(
     id="TwoLinkArmEnv-v1",
     entry_point="gym_twolinkarm_env.envs.gravity:TwoLinkArmEnvWithGravity",
+)
+
+register(
+    id="TwoLinkArmEnv-v2",
+    entry_point="gym_twolinkarm_env.envs.gravity_bottom:TwoLinkArmEnvWithGravityToBottom",
 )
\ No newline at end of file
